{% extends ac_app_name|add:'/auth/base.html' %}
{% block content %}
<div class="d-flex align-items-center pt-xl-5 px-5 ms-xl-4 pt-5 pt-xl-0 mt-xl-5">
    <form style="width: 23rem;" method="post" class="ajaxForm">
        {% csrf_token %}
        <h3 class="fw-normal mb-3 pb-3" style="letter-spacing: 1px;">{{_('request_account_activation')}}</h3>
        <div class="form-outline mb-4">
            <input type="text" id="id_email" name="email"
                   class="form-control form-control-lg"
                   autocomplete="email"/>
            <label class="form-label" for="id_email">{{ form.email.label }}</label>
        </div>
        <div class="pt-1 mb-4">
            <button class="btn btn-info btn-lg btn-block" type="submit">{{_('request_activation')}}</button>
        </div>
        <p class="small mb-2 mx-0 pb-lg-2"><a class="text-muted" href="{% url 'password_reset' %}">{{_('forgot_password')}}</a>
        </p>
        <p class="mx-0 mb-0">{{_('already_have_an_account')}}&nbsp;<a href="{% url 'login' %}"
                                                                      class="link-info">{{_('login')}}</a>
        </p>
        <p class="mx-0 mt-0">{{_('dont_have_an_account')}}&nbsp;<a href="{% url '__account_register' %}"
                                                                   class="link-info">{{_('register')}}</a>
        </p>
    </form>
</div>
{% endblock %}