# Generated by Django 5.0.4 on 2024-06-03 05:06

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='EmailTemplate',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('template', models.CharField(choices=[('REP', 'Reset Password'), ('REG', 'Register'), ('RAA', 'Request account activation')], max_length=5, unique=True)),
                ('content', models.TextField()),
            ],
        ),
        migrations.CreateModel(
            name='Discord',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('token_type', models.CharField(max_length=50)),
                ('access_token', models.CharField(max_length=500)),
                ('refresh_token', models.CharField(default=None, max_length=500, null=True)),
                ('expires_in', models.PositiveBigIntegerField()),
                ('date', models.DateTimeField(auto_now=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'Discord',
            },
        ),
        migrations.CreateModel(
            name='Google',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('id_token', models.TextField()),
                ('token_type', models.CharField(max_length=50)),
                ('access_token', models.CharField(max_length=500)),
                ('refresh_token', models.CharField(default=None, max_length=500, null=True)),
                ('expires_in', models.PositiveBigIntegerField()),
                ('date', models.DateTimeField(auto_now=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'Google',
            },
        ),
        migrations.CreateModel(
            name='Profile',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image_url', models.URLField(blank=True, db_comment='Profile image url of user.', null=True)),
                ('gender', models.CharField(choices=[('MA', 'Male'), ('FM', 'Female'), ('OT', 'Other')], default=None, max_length=3, null=True)),
                ('date_of_birth', models.DateField(blank=True, null=True)),
                ('phone_number', models.CharField(db_comment='Include with country code.', max_length=20, null=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Steam',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('steam_id', models.CharField(max_length=100, unique=True)),
                ('date', models.DateTimeField(auto_now=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'Steam',
            },
        ),
        migrations.CreateModel(
            name='Twitch',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('token_type', models.CharField(max_length=50)),
                ('access_token', models.CharField(max_length=500)),
                ('refresh_token', models.CharField(default=None, max_length=500, null=True)),
                ('expires_in', models.PositiveBigIntegerField()),
                ('date', models.DateTimeField(auto_now=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'Twitch',
            },
        ),
    ]
