{% load static %}
<!DOCTYPE html>
<html lang="en">
<head>
    <!--Include Header-->
    {% include ac_app_name|add:'/layouts/head_section.html' %}
    {% include ac_app_name|add:'/layouts/css_section.html' %}
</head>
<body>
{% include ac_app_name|add:'/layouts/page-loader.html' %}
<section class="vh-100">
    <div class="container-fluid">
        <div class="row">
            <!--Content-->
            <div class="col-sm-6 text-black">
                <div class="px-5 ms-xl-4">
                    <a href="/" class="me-3 pt-5 mt-xl-4 d-flex align-items-center">
                        <img src="{% static ac_logo %}" loading="lazy" decoding="async" width="80"/>
                        <span class="h1 fw-bold px-2">{{request.get_host}}</span>
                    </a>
                </div>
                {% block content %} {% endblock %}
            </div>
            <div class="col-sm-6 px-0 d-none d-sm-block">
                <img src="{% static ac_app_name|add:'/images/loginRegister.webp' %}"
                     loading="lazy" decoding="async"
                     alt="{{ _('login_image') }}" class="w-100 vh-100"
                     style="object-fit: cover; object-position: left;">
            </div>
        </div>
    </div>
</section>

<!--Include Js-->
{% include ac_app_name|add:'/layouts/js_section.html' %}

</body>
</html>

