{% extends ac_app_name|add:'/auth/base.html' %}
{% block content %}
<div class="d-flex align-items-center pt-xl-5 px-5 ms-xl-4 pt-5 pt-xl-0 mt-xl-5">
    <form style="width: 23rem;" method="post">
        {% csrf_token %}
        <h3 class="fw-normal mb-3 pb-3" style="letter-spacing: 1px;">{{_('reset_password')}}</h3>
        <div class="form-outline mb-0">
            <input type="email" id="id_email" name="email"
                   class="form-control form-control-lg"
                   autocomplete="email" value="{{form.email.value|default_if_none:''}}"/>
            <label class="form-label" for="id_email">{{ form.email.label }}</label>
        </div>
        <div class="text-danger">
            {% if form.email.errors %} {{form.email.errors}} {% endif %}
        </div>
        {% if form.email.errors %} {{form.email.help_text}} {% endif %}
        <div class="pt-1 mt-4">
            <button class="btn btn-info btn-lg btn-block" type="submit">
                {{_('request_password_reset')}}
            </button>
        </div>
        <p class="mx-0 mb-0 mt-4">{{_('already_have_an_account')}}&nbsp;<a href="{% url 'login' %}"
                                                                           class="link-info">{{_('login')}}</a>
        </p>
        <p class="mx-0 mt-0">{{_('dont_have_an_account')}}&nbsp;<a href="{% url '__account_register' %}"
                                                                   class="link-info">{{_('register')}}</a>
        </p>
    </form>
</div>
{% endblock %}